@@ -28,6 +28,12 @@
 #' Default is \code{-Inf}. For details, see \code{\link[glmnet]{glmnet}}.
 #' @param upper.limits Upper limits for coefficients.
 #' Default is \code{Inf}. For details, see \code{\link[glmnet]{glmnet}}.
+#' @param penalty.factor.init The multiplicative factor for the penalty
+#' applied to each coefficient in the initial estimation step. This is
+#' useful for incorporating prior information about variable weights,
+#' for example, emphasizing specific clinical variables. To make certain
+#' variables more likely to be selected, assign a smaller value.
+#' Default is \code{rep(1, ncol(x))}.
 #' @param seed Random seed for cross-validation fold division.
 #' @param parallel Logical. Enable parallel parameter tuning or not,
 #' default is {FALSE}. To enable parallel tuning, load the
@@ -51,45 +57,47 @@
 #' @export aenet
 #'
 #' @examples
-#' dat = msaenet.sim.gaussian(
+#' dat <- msaenet.sim.gaussian(
 #'   n = 150, p = 500, rho = 0.6,
 #'   coef = rep(1, 5), snr = 2, p.train = 0.7,
-#'   seed = 1001)
+#'   seed = 1001
+#' )
 #'
-#' aenet.fit = aenet(
+#' aenet.fit <- aenet(
 #'   dat$x.tr, dat$y.tr,
-#'   alphas = seq(0.2, 0.8, 0.2), seed = 1002)
+#'   alphas = seq(0.2, 0.8, 0.2), seed = 1002
+#' )
 #'
 #' print(aenet.fit)
 #' msaenet.nzv(aenet.fit)
 #' msaenet.fp(aenet.fit, 1:5)
 #' msaenet.tp(aenet.fit, 1:5)
-#' aenet.pred = predict(aenet.fit, dat$x.te)
+#' aenet.pred <- predict(aenet.fit, dat$x.te)
 #' msaenet.rmse(dat$y.te, aenet.pred)
 #' plot(aenet.fit)
-
-aenet = function(
+aenet <- function(
   x, y,
-  family = c('gaussian', 'binomial', 'poisson', 'cox'),
-  init   = c('enet', 'ridge'),
+  family = c("gaussian", "binomial", "poisson", "cox"),
+  init = c("enet", "ridge"),
   alphas = seq(0.05, 0.95, 0.05),
-  tune   = c('cv', 'ebic', 'bic', 'aic'),
-  nfolds = 5L, rule = c('lambda.min', 'lambda.1se'),
+  tune = c("cv", "ebic", "bic", "aic"),
+  nfolds = 5L, rule = c("lambda.min", "lambda.1se"),
   ebic.gamma = 1,
-  scale  = 1,
+  scale = 1,
   lower.limits = -Inf, upper.limits = Inf,
-  seed   = 1001, parallel = FALSE, verbose = FALSE) {
+  penalty.factor.init = rep(1, ncol(x)),
+  seed = 1001, parallel = FALSE, verbose = FALSE) {
 
-  family = match.arg(family)
-  init   = match.arg(init)
-  tune   = match.arg(tune)
-  rule   = match.arg(rule)
-  call   = match.call()
+  family <- match.arg(family)
+  init <- match.arg(init)
+  tune <- match.arg(tune)
+  rule <- match.arg(rule)
+  call <- match.call()
 
-  if (verbose) cat('Starting step 1 ...\n')
+  if (verbose) cat("Starting step 1 ...\n")
 
-  if (init == 'enet') {
-    enet.cv = msaenet.tune.glmnet(
+  if (init == "enet") {
+    enet.cv <- msaenet.tune.glmnet(
       x = x, y = y, family = family,
       alphas = alphas,
       tune = tune,
@@ -97,11 +105,13 @@ aenet = function(
       ebic.gamma = ebic.gamma,
       lower.limits = lower.limits,
       upper.limits = upper.limits,
-      seed = seed, parallel = parallel)
+      penalty.factor = penalty.factor.init,
+      seed = seed, parallel = parallel
+    )
   }
 
-  if (init == 'ridge') {
-    enet.cv = msaenet.tune.glmnet(
+  if (init == "ridge") {
+    enet.cv <- msaenet.tune.glmnet(
       x = x, y = y, family = family,
       alphas = 0,
       tune = tune,
@@ -109,28 +119,32 @@ aenet = function(
       ebic.gamma = ebic.gamma,
       lower.limits = lower.limits,
       upper.limits = upper.limits,
-      seed = seed, parallel = parallel)
+      penalty.factor = penalty.factor.init,
+      seed = seed, parallel = parallel
+    )
   }
 
-  best.alpha.enet     = enet.cv$'best.alpha'
-  best.lambda.enet    = enet.cv$'best.lambda'
-  step.criterion.enet = enet.cv$'step.criterion'
+  best.alpha.enet <- enet.cv$"best.alpha"
+  best.lambda.enet <- enet.cv$"best.lambda"
+  step.criterion.enet <- enet.cv$"step.criterion"
 
-  enet.full = glmnet(
+  enet.full <- glmnet(
     x = x, y = y, family = family,
-    alpha  = best.alpha.enet,
+    alpha = best.alpha.enet,
     lambda = best.lambda.enet,
     lower.limits = lower.limits,
-    upper.limits = upper.limits)
+    upper.limits = upper.limits,
+    penalty.factor = penalty.factor.init
+  )
 
-  bhat = as.matrix(enet.full$'beta')
-  if (all(bhat == 0)) bhat = rep(.Machine$double.eps * 2, length(bhat))
+  bhat <- as.matrix(enet.full$"beta")
+  if (all(bhat == 0)) bhat <- rep(.Machine$double.eps * 2, length(bhat))
 
-  adpen = (pmax(abs(bhat), .Machine$double.eps))^(-scale)
+  adpen <- (pmax(abs(bhat), .Machine$double.eps))^(-scale)
 
-  if (verbose) cat('Starting step 2 ...\n')
+  if (verbose) cat("Starting step 2 ...\n")
 
-  aenet.cv = msaenet.tune.glmnet(
+  aenet.cv <- msaenet.tune.glmnet(
     x = x, y = y, family = family,
     alphas = alphas,
     tune = tune,
@@ -139,38 +153,40 @@ aenet = function(
     lower.limits = lower.limits,
     upper.limits = upper.limits,
     seed = seed + 1L, parallel = parallel,
-    penalty.factor = adpen)
+    penalty.factor = adpen
+  )
 
-  best.alpha.aenet     = aenet.cv$'best.alpha'
-  best.lambda.aenet    = aenet.cv$'best.lambda'
-  step.criterion.aenet = aenet.cv$'step.criterion'
+  best.alpha.aenet <- aenet.cv$"best.alpha"
+  best.lambda.aenet <- aenet.cv$"best.lambda"
+  step.criterion.aenet <- aenet.cv$"step.criterion"
 
-  aenet.full = glmnet(
+  aenet.full <- glmnet(
     x = x, y = y, family = family,
-    alpha  = best.alpha.aenet,
+    alpha = best.alpha.aenet,
     lambda = best.lambda.aenet,
     lower.limits = lower.limits,
     upper.limits = upper.limits,
-    penalty.factor = adpen)
+    penalty.factor = adpen
+  )
 
   # final beta stored as sparse matrix
-  bhat.full = Matrix(aenet.full$'beta', sparse = TRUE)
+  bhat.full <- Matrix(aenet.full$"beta", sparse = TRUE)
 
-  aenet.model = list(
-    'beta'              = bhat.full,
-    'model'             = aenet.full,
-    'beta.first'        = enet.full$'beta',
-    'model.first'       = enet.full,
-    'best.alpha.enet'   = best.alpha.enet,
-    'best.alpha.aenet'  = best.alpha.aenet,
-    'best.lambda.enet'  = best.lambda.enet,
-    'best.lambda.aenet' = best.lambda.aenet,
-    'step.criterion'    = c(step.criterion.enet, step.criterion.aenet),
-    'adpen'             = adpen,
-    'seed'              = seed,
-    'call'              = call)
+  aenet.model <- list(
+    "beta" = bhat.full,
+    "model" = aenet.full,
+    "beta.first" = enet.full$"beta",
+    "model.first" = enet.full,
+    "best.alpha.enet" = best.alpha.enet,
+    "best.alpha.aenet" = best.alpha.aenet,
+    "best.lambda.enet" = best.lambda.enet,
+    "best.lambda.aenet" = best.lambda.aenet,
+    "step.criterion" = c(step.criterion.enet, step.criterion.aenet),
+    "adpen" = adpen,
+    "seed" = seed,
+    "call" = call
+  )
 
-  class(aenet.model) = c('msaenet', 'msaenet.aenet')
+  class(aenet.model) <- c("msaenet", "msaenet.aenet")
   aenet.model
-
 }
