@@ -13,29 +13,29 @@
 #' @export msaenet.nzv
 #'
 #' @examples
-#' dat = msaenet.sim.gaussian(
+#' dat <- msaenet.sim.gaussian(
 #'   n = 150, p = 500, rho = 0.6,
 #'   coef = rep(1, 5), snr = 2, p.train = 0.7,
-#'   seed = 1001)
-#'
-#' msaenet.fit = msaenet(
+#'   seed = 1001
+#' )
+#' 
+#' msaenet.fit <- msaenet(
 #'   dat$x.tr, dat$y.tr,
 #'   alphas = seq(0.2, 0.8, 0.2),
-#'   nsteps = 3L, seed = 1003)
-#'
+#'   nsteps = 3L, seed = 1003
+#' )
+#' 
 #' msaenet.nzv(msaenet.fit)
-#'
+#' 
 #' # coefficients of non-zero variables
 #' coef(msaenet.fit)[msaenet.nzv(msaenet.fit)]
-
-msaenet.nzv = function(object) {
-
-  if (!.is.msaenet(object))
+msaenet.nzv <- function(object) {
+  if (!.is.msaenet(object)) {
     stop('object class must be "msaenet"')
+  }
 
-  idx = which(abs(as.vector(object$'beta')) > .Machine$double.eps)
+  idx <- which(abs(as.vector(object$"beta")) > .Machine$double.eps)
   idx
-
 }
 
 #' Get Indices of Non-Zero Variables in All Steps
@@ -53,38 +53,38 @@ msaenet.nzv = function(object) {
 #' @export msaenet.nzv.all
 #'
 #' @examples
-#' dat = msaenet.sim.gaussian(
+#' dat <- msaenet.sim.gaussian(
 #'   n = 150, p = 500, rho = 0.6,
 #'   coef = rep(1, 5), snr = 2, p.train = 0.7,
-#'   seed = 1001)
-#'
-#' msaenet.fit = msaenet(
+#'   seed = 1001
+#' )
+#' 
+#' msaenet.fit <- msaenet(
 #'   dat$x.tr, dat$y.tr,
 #'   alphas = seq(0.2, 0.8, 0.2),
-#'   nsteps = 3L, seed = 1003)
-#'
+#'   nsteps = 3L, seed = 1003
+#' )
+#' 
 #' msaenet.nzv.all(msaenet.fit)
-
-msaenet.nzv.all = function(object) {
-
-  if (!.is.msaenet(object))
+msaenet.nzv.all <- function(object) {
+  if (!.is.msaenet(object)) {
     stop('object class must be "msaenet"')
+  }
 
   if (.is.multistep(object)) {
-    n = length(object$'beta.list')
-    idx = vector('list', n)
-    for (i in 1L:n) idx[[i]] =
-      which(abs(as.vector(object[['beta.list']][[i]])) > .Machine$double.eps)
+    n <- length(object$"beta.list")
+    idx <- vector("list", n)
+    for (i in 1L:n) idx[[i]] <-
+        which(abs(as.vector(object[["beta.list"]][[i]])) > .Machine$double.eps)
   }
 
   if (.is.adaptive(object)) {
-    idx = vector('list', 2L)
-    idx[[1L]] = which(abs(as.vector(object[['beta.first']])) > .Machine$double.eps)
-    idx[[2L]] = which(abs(as.vector(object[['beta']])) > .Machine$double.eps)
+    idx <- vector("list", 2L)
+    idx[[1L]] <- which(abs(as.vector(object[["beta.first"]])) > .Machine$double.eps)
+    idx[[2L]] <- which(abs(as.vector(object[["beta"]])) > .Machine$double.eps)
   }
 
   idx
-
 }
 
 #' Extract Model Coefficients
@@ -105,26 +105,26 @@ msaenet.nzv.all = function(object) {
 #' @export
 #'
 #' @examples
-#' dat = msaenet.sim.gaussian(
+#' dat <- msaenet.sim.gaussian(
 #'   n = 150, p = 500, rho = 0.6,
 #'   coef = rep(1, 5), snr = 2, p.train = 0.7,
-#'   seed = 1001)
-#'
-#' msaenet.fit = msaenet(
+#'   seed = 1001
+#' )
+#' 
+#' msaenet.fit <- msaenet(
 #'   dat$x.tr, dat$y.tr,
 #'   alphas = seq(0.2, 0.8, 0.2),
-#'   nsteps = 3L, seed = 1003)
-#'
+#'   nsteps = 3L, seed = 1003
+#' )
+#' 
 #' coef(msaenet.fit)
-
-coef.msaenet = function(object, ...) {
-
-  if (!.is.msaenet(object))
+coef.msaenet <- function(object, ...) {
+  if (!.is.msaenet(object)) {
     stop('object class must be "msaenet"')
+  }
 
-  bhat = as.vector(object$'beta')
+  bhat <- as.vector(object$"beta")
   bhat
-
 }
 
 #' Get the Number of False Positive Selections
@@ -144,25 +144,25 @@ coef.msaenet = function(object, ...) {
 #' @export msaenet.fp
 #'
 #' @examples
-#' dat = msaenet.sim.gaussian(
+#' dat <- msaenet.sim.gaussian(
 #'   n = 150, p = 500, rho = 0.6,
 #'   coef = rep(1, 5), snr = 2, p.train = 0.7,
-#'   seed = 1001)
-#'
-#' msaenet.fit = msaenet(
+#'   seed = 1001
+#' )
+#' 
+#' msaenet.fit <- msaenet(
 #'   dat$x.tr, dat$y.tr,
 #'   alphas = seq(0.2, 0.8, 0.2),
-#'   nsteps = 3L, seed = 1003)
-#'
+#'   nsteps = 3L, seed = 1003
+#' )
+#' 
 #' msaenet.fp(msaenet.fit, 1:5)
-
-msaenet.fp = function(object, true.idx) {
-
-  if (!.is.msaenet(object))
+msaenet.fp <- function(object, true.idx) {
+  if (!.is.msaenet(object)) {
     stop('object class must be "msaenet"')
+  }
 
   length(setdiff(msaenet.nzv(object), true.idx))
-
 }
 
 #' Get the Number of False Negative Selections
@@ -182,25 +182,25 @@ msaenet.fp = function(object, true.idx) {
 #' @export msaenet.fn
 #'
 #' @examples
-#' dat = msaenet.sim.gaussian(
+#' dat <- msaenet.sim.gaussian(
 #'   n = 150, p = 500, rho = 0.6,
 #'   coef = rep(1, 5), snr = 2, p.train = 0.7,
-#'   seed = 1001)
-#'
-#' msaenet.fit = msaenet(
+#'   seed = 1001
+#' )
+#' 
+#' msaenet.fit <- msaenet(
 #'   dat$x.tr, dat$y.tr,
 #'   alphas = seq(0.2, 0.8, 0.2),
-#'   nsteps = 3L, seed = 1003)
-#'
+#'   nsteps = 3L, seed = 1003
+#' )
+#' 
 #' msaenet.fn(msaenet.fit, 1:5)
-
-msaenet.fn = function(object, true.idx) {
-
-  if (!.is.msaenet(object))
+msaenet.fn <- function(object, true.idx) {
+  if (!.is.msaenet(object)) {
     stop('object class must be "msaenet"')
+  }
 
   length(setdiff(true.idx, msaenet.nzv(object)))
-
 }
 
 #' Get the Number of True Positive Selections
@@ -220,23 +220,23 @@ msaenet.fn = function(object, true.idx) {
 #' @export msaenet.tp
 #'
 #' @examples
-#' dat = msaenet.sim.gaussian(
+#' dat <- msaenet.sim.gaussian(
 #'   n = 150, p = 500, rho = 0.6,
 #'   coef = rep(1, 5), snr = 2, p.train = 0.7,
-#'   seed = 1001)
-#'
-#' msaenet.fit = msaenet(
+#'   seed = 1001
+#' )
+#' 
+#' msaenet.fit <- msaenet(
 #'   dat$x.tr, dat$y.tr,
 #'   alphas = seq(0.2, 0.8, 0.2),
-#'   nsteps = 3L, seed = 1003)
-#'
+#'   nsteps = 3L, seed = 1003
+#' )
+#' 
 #' msaenet.tp(msaenet.fit, 1:5)
-
-msaenet.tp = function(object, true.idx) {
-
-  if (!.is.msaenet(object))
+msaenet.tp <- function(object, true.idx) {
+  if (!.is.msaenet(object)) {
     stop('object class must be "msaenet"')
+  }
 
   length(intersect(msaenet.nzv(object), true.idx))
-
 }
