@@ -40,6 +40,12 @@
 #' Default is \code{-Inf}. For details, see \code{\link[glmnet]{glmnet}}.
 #' @param upper.limits Upper limits for coefficients.
 #' Default is \code{Inf}. For details, see \code{\link[glmnet]{glmnet}}.
+#' @param penalty.factor.init The multiplicative factor for the penalty
+#' applied to each coefficient in the initial estimation step. This is
+#' useful for incorporating prior information about variable weights,
+#' for example, emphasizing specific clinical variables. To make certain
+#' variables more likely to be selected, assign a smaller value.
+#' Default is \code{rep(1, ncol(x))}.
 #' @param seed Random seed for cross-validation fold division.
 #' @param parallel Logical. Enable parallel parameter tuning or not,
 #' default is {FALSE}. To enable parallel tuning, load the
@@ -63,59 +69,61 @@
 #' @export msaenet
 #'
 #' @examples
-#' dat = msaenet.sim.gaussian(
+#' dat <- msaenet.sim.gaussian(
 #'   n = 150, p = 500, rho = 0.6,
 #'   coef = rep(1, 5), snr = 2, p.train = 0.7,
-#'   seed = 1001)
+#'   seed = 1001
+#' )
 #'
-#' msaenet.fit = msaenet(
+#' msaenet.fit <- msaenet(
 #'   dat$x.tr, dat$y.tr,
 #'   alphas = seq(0.2, 0.8, 0.2),
-#'   nsteps = 3L, seed = 1003)
+#'   nsteps = 3L, seed = 1003
+#' )
 #'
 #' print(msaenet.fit)
 #' msaenet.nzv(msaenet.fit)
 #' msaenet.fp(msaenet.fit, 1:5)
 #' msaenet.tp(msaenet.fit, 1:5)
-#' msaenet.pred = predict(msaenet.fit, dat$x.te)
+#' msaenet.pred <- predict(msaenet.fit, dat$x.te)
 #' msaenet.rmse(dat$y.te, msaenet.pred)
 #' plot(msaenet.fit)
-
-msaenet = function(
+msaenet <- function(
   x, y,
-  family = c('gaussian', 'binomial', 'poisson', 'cox'),
-  init   = c('enet', 'ridge'),
+  family = c("gaussian", "binomial", "poisson", "cox"),
+  init = c("enet", "ridge"),
   alphas = seq(0.05, 0.95, 0.05),
-  tune   = c('cv', 'ebic', 'bic', 'aic'),
-  nfolds = 5L, rule = c('lambda.min', 'lambda.1se'),
+  tune = c("cv", "ebic", "bic", "aic"),
+  nfolds = 5L, rule = c("lambda.min", "lambda.1se"),
   ebic.gamma = 1,
   nsteps = 2L,
-  tune.nsteps = c('max', 'ebic', 'bic', 'aic'),
+  tune.nsteps = c("max", "ebic", "bic", "aic"),
   ebic.gamma.nsteps = 1,
-  scale  = 1,
+  scale = 1,
   lower.limits = -Inf, upper.limits = Inf,
-  seed   = 1001, parallel = FALSE, verbose = FALSE) {
+  penalty.factor.init = rep(1, ncol(x)),
+  seed = 1001, parallel = FALSE, verbose = FALSE) {
 
-  if (nsteps < 2L) stop('nsteps must be an integer >= 2')
+  if (nsteps < 2L) stop("nsteps must be an integer >= 2")
 
-  family      = match.arg(family)
-  init        = match.arg(init)
-  tune        = match.arg(tune)
-  rule        = match.arg(rule)
-  tune.nsteps = match.arg(tune.nsteps)
-  call        = match.call()
+  family <- match.arg(family)
+  init <- match.arg(init)
+  tune <- match.arg(tune)
+  rule <- match.arg(rule)
+  tune.nsteps <- match.arg(tune.nsteps)
+  call <- match.call()
 
-  best.alphas    = rep(NA, nsteps + 1L)
-  best.lambdas   = rep(NA, nsteps + 1L)
-  step.criterion = rep(NA, nsteps + 1L)
-  beta.list      = vector('list', nsteps + 1L)
-  model.list     = vector('list', nsteps + 1L)
-  adapen.list    = vector('list', nsteps)
+  best.alphas <- rep(NA, nsteps + 1L)
+  best.lambdas <- rep(NA, nsteps + 1L)
+  step.criterion <- rep(NA, nsteps + 1L)
+  beta.list <- vector("list", nsteps + 1L)
+  model.list <- vector("list", nsteps + 1L)
+  adapen.list <- vector("list", nsteps)
 
-  if (verbose) cat('Starting step 1 ...\n')
+  if (verbose) cat("Starting step 1 ...\n")
 
-  if (init == 'enet') {
-    model.cv = msaenet.tune.glmnet(
+  if (init == "enet") {
+    model.cv <- msaenet.tune.glmnet(
       x = x, y = y, family = family,
       alphas = alphas,
       tune = tune,
@@ -123,11 +131,13 @@ msaenet = function(
       ebic.gamma = ebic.gamma,
       lower.limits = lower.limits,
       upper.limits = upper.limits,
-      seed = seed, parallel = parallel)
+      penalty.factor = penalty.factor.init,
+      seed = seed, parallel = parallel
+    )
   }
 
-  if (init == 'ridge') {
-    model.cv = msaenet.tune.glmnet(
+  if (init == "ridge") {
+    model.cv <- msaenet.tune.glmnet(
       x = x, y = y, family = family,
       alphas = 0,
       tune = tune,
@@ -135,39 +145,42 @@ msaenet = function(
       ebic.gamma = ebic.gamma,
       lower.limits = lower.limits,
       upper.limits = upper.limits,
-      seed = seed, parallel = parallel)
+      penalty.factor = penalty.factor.init,
+      seed = seed, parallel = parallel
+    )
   }
 
-  best.alphas[[1L]]    = model.cv$'best.alpha'
-  best.lambdas[[1L]]   = model.cv$'best.lambda'
-  step.criterion[[1L]] = model.cv$'step.criterion'
+  best.alphas[[1L]] <- model.cv$"best.alpha"
+  best.lambdas[[1L]] <- model.cv$"best.lambda"
+  step.criterion[[1L]] <- model.cv$"step.criterion"
 
-  model.list[[1L]] = glmnet(
+  model.list[[1L]] <- glmnet(
     x = x, y = y, family = family,
-    alpha  = best.alphas[[1L]],
+    alpha = best.alphas[[1L]],
     lambda = best.lambdas[[1L]],
     lower.limits = lower.limits,
-    upper.limits = upper.limits)
+    upper.limits = upper.limits,
+    penalty.factor = penalty.factor.init
+  )
 
-  if (.df(model.list[[1L]]) < 0.5)
-    stop('Null model produced by the full fit (all coefficients are zero).
-         Please try a different parameter setting.')
+  if (.df(model.list[[1L]]) < 0.5) {
+    stop("Null model produced by the full fit (all coefficients are zero). Please try a different parameter setting.")
+  }
 
-  bhat = as.matrix(model.list[[1L]][['beta']])
-  if (all(bhat == 0)) bhat = rep(.Machine$double.eps * 2, length(bhat))
-  beta.list[[1L]] = bhat
+  bhat <- as.matrix(model.list[[1L]][["beta"]])
+  if (all(bhat == 0)) bhat <- rep(.Machine$double.eps * 2, length(bhat))
+  beta.list[[1L]] <- bhat
 
   # MSAEnet steps
   for (i in 1L:nsteps) {
+    adpen.raw <- (pmax(abs(beta.list[[i]]), .Machine$double.eps))^(-scale)
+    adapen.list[[i]] <- as.vector(adpen.raw)
+    adpen.name <- rownames(adpen.raw)
+    names(adapen.list[[i]]) <- adpen.name
 
-    adpen.raw = (pmax(abs(beta.list[[i]]), .Machine$double.eps))^(-scale)
-    adapen.list[[i]] = as.vector(adpen.raw)
-    adpen.name = rownames(adpen.raw)
-    names(adapen.list[[i]]) = adpen.name
+    if (verbose) cat("Starting step", i + 1, "...\n")
 
-    if (verbose) cat('Starting step', i + 1, '...\n')
-
-    model.cv = msaenet.tune.glmnet(
+    model.cv <- msaenet.tune.glmnet(
       x = x, y = y, family = family,
       alphas = alphas,
       tune = tune,
@@ -176,52 +189,54 @@ msaenet = function(
       lower.limits = lower.limits,
       upper.limits = upper.limits,
       seed = seed + i, parallel = parallel,
-      penalty.factor = adapen.list[[i]])
+      penalty.factor = adapen.list[[i]]
+    )
 
-    best.alphas[[i + 1L]]    = model.cv$'best.alpha'
-    best.lambdas[[i + 1L]]   = model.cv$'best.lambda'
-    step.criterion[[i + 1L]] = model.cv$'step.criterion'
+    best.alphas[[i + 1L]] <- model.cv$"best.alpha"
+    best.lambdas[[i + 1L]] <- model.cv$"best.lambda"
+    step.criterion[[i + 1L]] <- model.cv$"step.criterion"
 
-    model.list[[i + 1L]] = glmnet(
+    model.list[[i + 1L]] <- glmnet(
       x = x, y = y, family = family,
       alpha = best.alphas[[i + 1L]],
       lambda = best.lambdas[[i + 1L]],
       lower.limits = lower.limits,
       upper.limits = upper.limits,
-      penalty.factor = adapen.list[[i]])
+      penalty.factor = adapen.list[[i]]
+    )
 
-    if (.df(model.list[[i + 1L]]) < 0.5)
-      stop('Null model produced by the full fit (all coefficients are zero).
-           Please try a different parameter setting.')
-
-    bhat = as.matrix(model.list[[i + 1L]][['beta']])
-    if (all(bhat == 0)) bhat = rep(.Machine$double.eps * 2, length(bhat))
-    beta.list[[i + 1L]] = bhat
+    if (.df(model.list[[i + 1L]]) < 0.5) {
+      stop("Null model produced by the full fit (all coefficients are zero). Please try a different parameter setting.")
+    }
 
+    bhat <- as.matrix(model.list[[i + 1L]][["beta"]])
+    if (all(bhat == 0)) bhat <- rep(.Machine$double.eps * 2, length(bhat))
+    beta.list[[i + 1L]] <- bhat
   }
 
   # select optimal step
-  post.ics = msaenet.tune.nsteps.glmnet(
-    model.list, tune.nsteps, ebic.gamma.nsteps)
+  post.ics <- msaenet.tune.nsteps.glmnet(
+    model.list, tune.nsteps, ebic.gamma.nsteps
+  )
 
-  best.step = post.ics$'best.step'
-  post.criterion = post.ics$'ics'
+  best.step <- post.ics$"best.step"
+  post.criterion <- post.ics$"ics"
 
-  msaenet.model = list(
-    'beta'           = Matrix(beta.list[[best.step]], sparse = TRUE),
-    'model'          = model.list[[best.step]],
-    'best.step'      = best.step,
-    'best.alphas'    = best.alphas,
-    'best.lambdas'   = best.lambdas,
-    'step.criterion' = step.criterion,
-    'post.criterion' = post.criterion,
-    'beta.list'      = beta.list,
-    'model.list'     = model.list,
-    'adapen.list'    = adapen.list,
-    'seed'           = seed,
-    'call'           = call)
+  msaenet.model <- list(
+    "beta" = Matrix(beta.list[[best.step]], sparse = TRUE),
+    "model" = model.list[[best.step]],
+    "best.step" = best.step,
+    "best.alphas" = best.alphas,
+    "best.lambdas" = best.lambdas,
+    "step.criterion" = step.criterion,
+    "post.criterion" = post.criterion,
+    "beta.list" = beta.list,
+    "model.list" = model.list,
+    "adapen.list" = adapen.list,
+    "seed" = seed,
+    "call" = call
+  )
 
-  class(msaenet.model) = c('msaenet', 'msaenet.msaenet')
+  class(msaenet.model) <- c("msaenet", "msaenet.msaenet")
   msaenet.model
-
 }
